<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AccountItem</name>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Sychroniseren voltooid</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="vanished">Netwerkfout</translation>
    </message>
    <message>
        <source>Server exception</source>
        <translation type="vanished">Serveruitzondering</translation>
    </message>
    <message>
        <source>Storage full</source>
        <translation type="vanished">Geen vrije schijfruimte</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>Local account</source>
        <translation type="vanished">Lokaal account</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Soorten afspraken</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <source>Color</source>
        <translation type="vanished">Kleur</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Opslaan</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation type="vanished">Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="vanished">Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="vanished">Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="vanished">Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="vanished">Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="vanished">Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Zondag</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Maan</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <source>%1 more</source>
        <translation type="vanished">Nog %1 andere</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <source>My Event</source>
        <translation type="vanished">Mijn afspraak</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Oké</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>Edit</source>
        <comment>button</comment>
        <translation type="vanished">Bewerken</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Nieuw soort afspraak</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="vanished">Afspraak bewerken</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation type="vanished">De eindtijd moet later zijn dan de begintijd</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Oké</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">Nooit</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation type="vanished">Bij aanvang</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation type="vanished">15 minuten van tevoren</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation type="vanished">30 minuten van tevoren</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation type="vanished">1 uur van tevoren</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation type="vanished">1 dag van tevoren</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation type="vanished">2 dagen van tevoren</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation type="vanished">1 week van tevoren</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation type="vanished">Op de dag van de afspraak (9:00 AM)</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation type="vanished">keer</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Voer een naam in</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">De naam mag niet alleen uit spaties bestaan</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="vanished">Soort:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Omschrijving:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation type="vanished">Hele dag:</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation type="vanished">Begint om:</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation type="vanished">Eindigt om:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation type="vanished">Herinneren:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="vanished">Herhalen:</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation type="vanished">Herhaling eindigt op:</translation>
    </message>
    <message>
        <source>Calendar account:</source>
        <translation type="vanished">Agenda-account:</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Agenda-account</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Soort</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Omschrijving</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Hele dag</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="vanished">Tijdstip:</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Tijdstip</translation>
    </message>
    <message>
        <source>Solar</source>
        <translation type="vanished">Zon</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">Maan</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation type="vanished">Begint om</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation type="vanished">Eindigt om</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation type="vanished">Herinneren</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="vanished">Herhalen</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="vanished">Dagelijks</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="vanished">Weekdagen</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="vanished">Wekelijks</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="vanished">Maandelijks</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation type="vanished">Jaarlijks</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation type="vanished">Herhaling eindigt op</translation>
    </message>
    <message>
        <source>After</source>
        <translation type="vanished">Na</translation>
    </message>
    <message>
        <source>On</source>
        <translation type="vanished">Op</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Opslaan</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation type="vanished">Alle afspraken in de reeks moeten voorzien zijn van de status ‘hele dag’.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation type="vanished">Wil je alle afspraken in de reeks bewerken?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Annuleren</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation type="vanished">Reeks bewerken</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation type="vanished">Je past de herhaalinstellingen van deze afspraak aan.</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation type="vanished">Je staat op het punt een afspraak te verwijderen.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation type="vanished">Weet je zeker dat je deze afspraak wilt verwijderen?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Wil je alle afspraken in de reeks verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation type="vanished">Reeks verwijderen</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation type="vanished">Deze afspraak verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Wil je deze en toekomstige afspraken verwijderen of enkel de deze?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation type="vanished">Toekomstige afspraken verwijderen</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation type="vanished">Je staat op het punt een reeks aan te passen.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation type="vanished">Wil je deze en toekomstige afspraken aanpassen of enkel deze?</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="vanished">Reeks</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation type="vanished">Deze afspraak</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation type="vanished">Wil je deze en toekomstige afspraken aanpassen of enkel deze?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation type="vanished">Toekomstige afspraken</translation>
    </message>
    <message>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation type="vanished">Je hebt een schrikkelmaand gekozen. De herinnering wordt op basis van de maankalender getoond.</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">Oké</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Bewerken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Hele dag</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">Geen zoekresultaten</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation type="vanished">HELE DAG</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <source>Manual</source>
        <translation type="vanished">Handmatig</translation>
    </message>
    <message>
        <source>15 mins</source>
        <translation type="vanished">15 min.</translation>
    </message>
    <message>
        <source>30 mins</source>
        <translation type="vanished">30 min.</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="vanished">1 uur</translation>
    </message>
    <message>
        <source>24 hours</source>
        <translation type="vanished">24 uur</translation>
    </message>
    <message>
        <source>Sync Now</source>
        <translation type="vanished">Nu synchroniseren</translation>
    </message>
    <message>
        <source>Last sync</source>
        <translation type="vanished">Recentste synchronisatie</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="vanished">maandag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">zondag</translation>
    </message>
    <message>
        <source>12-hour clock</source>
        <translation type="vanished">12-uursklok</translation>
    </message>
    <message>
        <source>24-hour clock</source>
        <translation type="vanished">24-uursklok</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <source>(%1 mins)</source>
        <translation type="vanished">(%1 min.)</translation>
    </message>
    <message>
        <source>(%1 hour)</source>
        <translation type="vanished">(%1 uur)</translation>
    </message>
    <message>
        <source>(%1 hours)</source>
        <translation type="vanished">(%1 uur)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="vanished">W</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">D</translation>
    </message>
    <message>
        <source>Search events and festivals</source>
        <translation type="vanished">Zoeken naar afspraken en evenementen</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation type="vanished">zo</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation type="vanished">ma</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation type="vanished">di</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation type="vanished">woe</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation type="vanished">do</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation type="vanished">vrij</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation type="vanished">za</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation type="vanished">Week</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Hele dag</translation>
    </message>
    <message>
        <source>No event</source>
        <translation type="vanished">Geen afspraak</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Kalender</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation type="vanished">Met Kalender kun je je afspraken en planning beheren, zowel werk als privé.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Kalender</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">Instellingen</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Privacybeleid</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="vanished">Bezig met synchroniseren…</translation>
    </message>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">Sychroniseren voltooid</translation>
    </message>
    <message>
        <source>Sync failed, please try later</source>
        <translation type="vanished">Synchroniseren mislukt - probeer het later opnieuw</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Hele dag</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Werk</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Privé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Eén dag van tevoren</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Herinner me morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Herinner me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 min. later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 uur later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 uur later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Herinnering inplannen</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>van %1 tot %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Aanpassen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>New event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <source>You are deleting an event type.</source>
        <translation type="vanished">Je staat op het punt om een afspraaktype te verwijderen.</translation>
    </message>
    <message>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation type="vanished">Alle bijbehorende afspraken worden verwijderd en kunnen niet worden hersteld.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Verwijderen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Account settings</source>
        <translation type="vanished">Accountinstellingen</translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="vanished">Account</translation>
    </message>
    <message>
        <source>Select items to be synced</source>
        <translation type="vanished">Selecteer de te synchroniseren items</translation>
    </message>
    <message>
        <source>Events</source>
        <translation type="vanished">Afspraken</translation>
    </message>
    <message>
        <source>General settings</source>
        <translation type="vanished">Algemene instellingen</translation>
    </message>
    <message>
        <source>Sync interval</source>
        <translation type="vanished">Synchroniseren, elke</translation>
    </message>
    <message>
        <source>Manage calendar</source>
        <translation type="vanished">Agenda beheren</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">Agenda-account</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">Soorten afspraken</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Algemeen</translation>
    </message>
    <message>
        <source>First day of week</source>
        <translation type="vanished">Eerste dag van de week</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">Tijdsklok</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="vanished">Vandaag</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="vanished">Vandaag</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">Nieuw soort afspraak</translation>
    </message>
    <message>
        <source>Edit event type</source>
        <translation type="vanished">Afspraaktype bewerken</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Naam:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="vanished">Kleur:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Opslaan</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">De naam mag niet alleen bestaan uit spaties</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">Voer een naam in</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Hulp</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation type="vanished">Afspraak verwijderen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopiëren</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Knippen</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Plakken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="vanished">Alles selecteren</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <source>Go</source>
        <comment>button</comment>
        <translation type="vanished">Ga</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <source>Sign In</source>
        <comment>button</comment>
        <translation type="vanished">Inloggen</translation>
    </message>
    <message>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation type="vanished">Uitloggen</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation type="vanished">J</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="vanished">Vandaag</translation>
    </message>
</context>
</TS>